@@ -5,7 +5,7 @@
 
 //! Scatter Gather Data Wrapper.
 
-#![doc(html_root_url = "https://docs.rs/rexsgdata/0.11.1")]
+#![doc(html_root_url = "https://docs.rs/rexsgdata/0.11.4")]
 #![cfg_attr(feature = "pedantic", warn(clippy::pedantic))]
 #![warn(clippy::use_self)]
 #![warn(deprecated_in_future)]
@@ -16,9 +16,8 @@
 #![warn(rust_2018_idioms)]
 #![warn(unused)]
 #![deny(warnings)]
-#![feature(test)]
-
-#[cfg(test)]
+#![cfg_attr(feature = "nightly_features", feature(test))]
+#[cfg(feature = "nightly_features")]
 extern crate test;
 
 pub use crate::iovec::Iovec;
