@@ -336,15 +336,15 @@ mod tests {
             assert_eq!(deser_a, deser_b);
 
             drain_data_compare(
-                &data_a,
+                data_a,
                 partition_vec(vec![42; data_a.capacity()].as_slice()),
             );
 
             // create a vector of vector where one is of size 1
-            drain_data_compare(&data_a, vec![vec![42; data_a.capacity() - 1], vec![44; 1]]);
+            drain_data_compare(data_a, vec![vec![42; data_a.capacity() - 1], vec![44; 1]]);
 
             // create a vector of vector where one is of size 1
-            drain_data_compare(&data_a, vec![vec![44; 1], vec![42; data_a.capacity() - 1]]);
+            drain_data_compare(data_a, vec![vec![44; 1], vec![42; data_a.capacity() - 1]]);
 
             //Drain data into masked sgvec - add compare values
             drain_data_compare(
@@ -369,7 +369,7 @@ mod tests {
     // Test that they are (not)-eqaul after mutation.
     fn compare_data(data_a: &mut SgData, data_b: &mut SgData) {
         // Generate two sg-datas of different types with equal byte-wise values.
-        eq_data(&data_a, &data_b, None);
+        eq_data(data_a, data_b, None);
 
         let capacity = data_a.capacity();
 
@@ -384,8 +384,8 @@ mod tests {
         assert_ne!(data_a, data_b);
 
         eq_data(
-            &data_a,
-            &data_b,
+            data_a,
+            data_b,
             Range {
                 start: 0,
                 end: capacity,
@@ -404,8 +404,8 @@ mod tests {
             assert_ne!(data_a, data_c);
 
             eq_data(
-                &data_a,
-                &data_c,
+                data_a,
+                data_c,
                 Range {
                     start: 1,
                     end: data_a.capacity(),
@@ -414,8 +414,8 @@ mod tests {
 
             assert_ne!(data_b, data_c);
             eq_data(
-                &data_b,
-                &data_c,
+                data_b,
+                data_c,
                 Range {
                     start: 1,
                     end: data_b.capacity(),
@@ -562,60 +562,64 @@ mod tests {
         assert_eq!(data_combined.to_vec(), vec_copied);
     }
 
-    use test::Bencher;
+    #[cfg(feature = "nightly_features")]
+    mod benches {
+        use super::*;
+        use test::Bencher;
 
-    #[bench]
-    fn direct_serialize(b: &mut Bencher) {
-        let data: SgData = SgData::from(vec![0x45_u8; 8192]);
+        #[bench]
+        fn direct_serialize(b: &mut Bencher) {
+            let data: SgData = SgData::from(vec![0x45_u8; 8192]);
 
-        b.iter(|| serialize(&data).unwrap())
-    }
+            b.iter(|| serialize(&data).unwrap())
+        }
 
-    #[bench]
-    fn direct_deserialize(b: &mut Bencher) {
-        let data: SgData = SgData::from(vec![0x45_u8; 8192]);
-        let buf = serialize(&data).unwrap();
+        #[bench]
+        fn direct_deserialize(b: &mut Bencher) {
+            let data: SgData = SgData::from(vec![0x45_u8; 8192]);
+            let buf = serialize(&data).unwrap();
 
-        b.iter(|| deserialize::<SgData>(&buf).unwrap());
-    }
+            b.iter(|| deserialize::<SgData>(&buf).unwrap());
+        }
 
-    #[bench]
-    fn sglist_serialize(b: &mut Bencher) {
-        let sgvec = vec![vec![0x45_u8; 4096]; 2];
-        let data: SgData = unsafe { SgData::from_sglist(create_sglist(sgvec)) };
+        #[bench]
+        fn sglist_serialize(b: &mut Bencher) {
+            let sgvec = vec![vec![0x45_u8; 4096]; 2];
+            let data: SgData = unsafe { SgData::from_sglist(create_sglist(sgvec)) };
 
-        b.iter(|| serialize(&data).unwrap())
-    }
+            b.iter(|| serialize(&data).unwrap())
+        }
 
-    #[bench]
-    fn sglist_deserialize(b: &mut Bencher) {
-        let sgvec = vec![vec![0x45_u8; 4096]; 2];
-        let data: SgData = unsafe { SgData::from_sglist(create_sglist(sgvec)) };
-        let buf = serialize(&data).unwrap();
+        #[bench]
+        fn sglist_deserialize(b: &mut Bencher) {
+            let sgvec = vec![vec![0x45_u8; 4096]; 2];
+            let data: SgData = unsafe { SgData::from_sglist(create_sglist(sgvec)) };
+            let buf = serialize(&data).unwrap();
 
-        b.iter(|| deserialize::<SgData>(&buf).unwrap());
-    }
+            b.iter(|| deserialize::<SgData>(&buf).unwrap());
+        }
 
-    #[bench]
-    fn iovec_serialize(b: &mut Bencher) {
-        let data: SgData = vec![vec![0x46; 4096]; 2]
-            .into_iter()
-            .map(vec_into_iovec)
-            .map(Iovec::from)
-            .collect();
+        #[bench]
+        fn iovec_serialize(b: &mut Bencher) {
+            let data: SgData = vec![vec![0x46; 4096]; 2]
+                .into_iter()
+                .map(vec_into_iovec)
+                .map(Iovec::from)
+                .collect();
 
-        b.iter(|| serialize(&data).unwrap())
-    }
+            b.iter(|| serialize(&data).unwrap())
+        }
 
-    #[bench]
-    fn iovec_deserialize(b: &mut Bencher) {
-        let data: SgData = vec![vec![0x46; 4096]; 2]
-            .into_iter()
-            .map(vec_into_iovec)
-            .map(Iovec::from)
-            .collect();
-        let buf = serialize(&data).unwrap();
+        #[bench]
+        fn iovec_deserialize(b: &mut Bencher) {
+            let data: SgData = vec![vec![0x46; 4096]; 2]
+                .into_iter()
+                .map(vec_into_iovec)
+                .map(Iovec::from)
+                .collect();
+            let buf = serialize(&data).unwrap();
 
-        b.iter(|| deserialize::<SgData>(&buf).unwrap());
+            b.iter(|| deserialize::<SgData>(&buf).unwrap());
+        }
     }
 }
